@@ -1,4 +1,4 @@
-/* $Id: read.c,v 1.24 2006/04/10 08:41:46 bdejean Exp $ */
+/* $Id: read.c,v 1.16 2003/10/20 21:33:01 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,8 +23,7 @@
 
 #include <config.h>
 #include <glibtop/read.h>
-#include <glibtop/error.h>
-#include <glib/gi18n-lib.h>
+#include <libgnome/gnome-i18n.h>
 
 
 /* Reads some data from server. */
@@ -32,38 +31,49 @@
 static void
 do_read (int s, void *ptr, size_t total_size)
 {
-	ssize_t nread;
+	int nread;
+	size_t already_read = 0, remaining = total_size;
+	char *tmp_ptr;
+	
+	while (already_read < total_size) {
+		nread = recv (s, ptr, remaining, 0);
 
-	if(!total_size) return;
-
-	while (total_size && (nread = recv (s, ptr, total_size, 0)) > 0) {
-		total_size -= nread;
-		ptr = (char*)ptr + nread;
+		if (nread == 0) {
+			close (s);
+			continue;
+		}
+		
+		if (nread <= 0) {
+			glibtop_error_io ("recv");
+			return;
+		}
+		
+		already_read += nread;
+		remaining -= nread;
+		/* (char *) ptr += nread; */
+		tmp_ptr = ptr;
+		tmp_ptr += nread;
+		ptr = tmp_ptr;
 	}
-
-	if(nread == 0)
-		close (s);
-	else if (nread < 0)
-		glibtop_error_io ("recv");
 }
 
 void
 glibtop_read_l (glibtop *server, size_t size, void *buf)
 {
+	int ret = 0;
+
 	glibtop_init_r (&server, 0, 0);
 
 #ifdef DEBUG
-	fprintf (stderr, "LIBRARY: really reading %d bytes.\n", (int)size);
+	fprintf (stderr, "LIBRARY: really reading %d bytes.\n", size);
 #endif
 
 	if (server->socket) {
 		do_read (server->socket, buf, size);
 	} else {
-		if(read (server->input [0], buf, size) < 0)
-			glibtop_error_io_r (
-				server,
-				ngettext ("read %d byte",
-					  "read %d bytes", size),
-				(int)size);
+		ret = read (server->input [0], buf, size);
 	}
+
+	if (ret < 0)
+		glibtop_error_io_r (server, ngettext ("read %d byte", "read %d bytes", size), size);
 }
