@@ -1,4 +1,4 @@
-/* $Id: procargs.c,v 1.7.4.2 1999/05/27 14:04:01 martin Exp $ */
+/* $Id: procargs.c,v 1.19 2003/10/20 15:19:50 hadess Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -23,7 +23,6 @@
 
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/procargs.h>
 
 #include <glibtop_suid.h>
@@ -94,7 +93,7 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 		size += strlen (*ptr)+1;
 
 	size += 2;
-	retval = glibtop_malloc_r (server, size);
+	retval = g_malloc (server, size);
 	memset (retval, 0, size);
 
 	for (ptr = args; *ptr; ptr++) {
