@@ -1,4 +1,4 @@
-/* $Id: procuid.c,v 1.11 2004/03/04 15:29:16 hadess Exp $ */
+/* $Id: procuid.c,v 1.10 2003/10/20 21:27:27 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,7 @@
 
 #include <glibtop.h>
 #include <glibtop/procuid.h>
-#include "libgtop-i18n.h"
+#include <libgnome/gnome-i18n.h>
 
 const char *glibtop_names_proc_uid [GLIBTOP_MAX_PROC_UID] =
 {
