@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: swap.c,v 1.14 2003/10/19 16:55:49 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,20 +28,16 @@ static const unsigned long _glibtop_sysdeps_swap = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_swap_s (glibtop *server)
 {
-    server->sysdeps.swap = _glibtop_sysdeps_swap;
-
-    return 0;
+	server->sysdeps.swap = _glibtop_sysdeps_swap;
 }
 
 /* Provides information about swap usage. */
 
-int
+void
 glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 {
-    memset (buf, 0, sizeof (glibtop_swap));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_swap));
 }
